@@ -17,6 +17,9 @@ extern "C"
 #include "json/JSON_parser.h"
 }
 
+class ProximitySensor;
+class CameraKey;
+
 class Config
 {
 	private:
@@ -35,15 +38,23 @@ class Config
 
 		ProximitySensor* ps;
 		CameraKey* ck;
-		void writeConfigFile();	
 		
 		
 	public:
 		Config(ProximitySensor* ps_, CameraKey* ck_);
 		~Config();
 		int readConfig();
+		void writeConfigFile();	
+
+		int proximityVibrateOn;
 		int proximityOn;
 		int camerakeyOn;
+		std::string ps_shortPress;
+		std::string ps_longPress;
+		std::string ps_hold;
+		std::string ck_shortPress;
+		std::string ck_longPress;
+
 		void setProximity(ProximitySensor* ps_);
 		void setCameraKey(CameraKey* ck_);
 
